@@ -117,6 +117,9 @@ class JsonContainerProperty(JsonProperty):
             item_type = item_type()
         if hasattr(item_type, '_type'):
             item_type = item_type._type
+        if isinstance(item_type, tuple):
+            # this is for the case where item_type = (int, long)
+            item_type = item_type[0]
         self.item_type = item_type
         if item_type and item_type not in tuple(ALLOWED_PROPERTY_TYPES) \
                 and not issubclass(item_type, JsonObject):
@@ -137,7 +140,7 @@ class JsonContainerProperty(JsonProperty):
     def unwrap(self, obj):
         if not isinstance(obj, self._type):
             raise BadValueError(
-                '{0} is not an instance of {1}'.format(obj, self._type.__name__)
+                '{0!r} is not an instance of {1!r}'.format(obj, self._type.__name__)
             )
         if isinstance(obj, self.container_class):
             return obj, obj._obj
@@ -173,7 +176,7 @@ class AssertTypeProperty(JsonProperty):
 
     def assert_type(self, obj):
         if not isinstance(obj, self._type):
-            raise BadValueError('{0} not of type {1}'.format(obj, self._type))
+            raise BadValueError('{0!r} not of type {1!r}'.format(obj, self._type))
 
     def selective_coerce(self, obj):
         return obj
@@ -652,7 +655,7 @@ class JsonObjectBase(object):
                 self[name] = value
             else:
                 raise AttributeError(
-                    "{0} is not defined in schema "
+                    "{0!r} is not defined in schema "
                     "(not a valid property)".format(name)
                 )
         else:
